import { JupyterLabPlugin } from "@jupyterlab/application";
import "../style/index.css";
/**
 * Initialization data for the jupyterlab-jupytext extension.
 */
declare const extension: JupyterLabPlugin<void>;
export default extension;
